# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.managed_api import ManagedApi


class TestManagedApi(unittest.TestCase):
    """ManagedApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ManagedApi()

    def tearDown(self) -> None:
        pass

    def test_managed_blueprints_apply_create(self) -> None:
        """Test case for managed_blueprints_apply_create

        """
        pass

    def test_managed_blueprints_available_list(self) -> None:
        """Test case for managed_blueprints_available_list

        """
        pass

    def test_managed_blueprints_create(self) -> None:
        """Test case for managed_blueprints_create

        """
        pass

    def test_managed_blueprints_destroy(self) -> None:
        """Test case for managed_blueprints_destroy

        """
        pass

    def test_managed_blueprints_list(self) -> None:
        """Test case for managed_blueprints_list

        """
        pass

    def test_managed_blueprints_partial_update(self) -> None:
        """Test case for managed_blueprints_partial_update

        """
        pass

    def test_managed_blueprints_retrieve(self) -> None:
        """Test case for managed_blueprints_retrieve

        """
        pass

    def test_managed_blueprints_update(self) -> None:
        """Test case for managed_blueprints_update

        """
        pass

    def test_managed_blueprints_used_by_list(self) -> None:
        """Test case for managed_blueprints_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
