# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.providers_api import ProvidersApi


class TestProvidersApi(unittest.TestCase):
    """ProvidersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProvidersApi()

    def tearDown(self) -> None:
        pass

    def test_providers_all_destroy(self) -> None:
        """Test case for providers_all_destroy

        """
        pass

    def test_providers_all_list(self) -> None:
        """Test case for providers_all_list

        """
        pass

    def test_providers_all_retrieve(self) -> None:
        """Test case for providers_all_retrieve

        """
        pass

    def test_providers_all_types_list(self) -> None:
        """Test case for providers_all_types_list

        """
        pass

    def test_providers_all_used_by_list(self) -> None:
        """Test case for providers_all_used_by_list

        """
        pass

    def test_providers_google_workspace_create(self) -> None:
        """Test case for providers_google_workspace_create

        """
        pass

    def test_providers_google_workspace_destroy(self) -> None:
        """Test case for providers_google_workspace_destroy

        """
        pass

    def test_providers_google_workspace_groups_create(self) -> None:
        """Test case for providers_google_workspace_groups_create

        """
        pass

    def test_providers_google_workspace_groups_destroy(self) -> None:
        """Test case for providers_google_workspace_groups_destroy

        """
        pass

    def test_providers_google_workspace_groups_list(self) -> None:
        """Test case for providers_google_workspace_groups_list

        """
        pass

    def test_providers_google_workspace_groups_retrieve(self) -> None:
        """Test case for providers_google_workspace_groups_retrieve

        """
        pass

    def test_providers_google_workspace_groups_used_by_list(self) -> None:
        """Test case for providers_google_workspace_groups_used_by_list

        """
        pass

    def test_providers_google_workspace_list(self) -> None:
        """Test case for providers_google_workspace_list

        """
        pass

    def test_providers_google_workspace_partial_update(self) -> None:
        """Test case for providers_google_workspace_partial_update

        """
        pass

    def test_providers_google_workspace_retrieve(self) -> None:
        """Test case for providers_google_workspace_retrieve

        """
        pass

    def test_providers_google_workspace_sync_object_create(self) -> None:
        """Test case for providers_google_workspace_sync_object_create

        """
        pass

    def test_providers_google_workspace_sync_status_retrieve(self) -> None:
        """Test case for providers_google_workspace_sync_status_retrieve

        """
        pass

    def test_providers_google_workspace_update(self) -> None:
        """Test case for providers_google_workspace_update

        """
        pass

    def test_providers_google_workspace_used_by_list(self) -> None:
        """Test case for providers_google_workspace_used_by_list

        """
        pass

    def test_providers_google_workspace_users_create(self) -> None:
        """Test case for providers_google_workspace_users_create

        """
        pass

    def test_providers_google_workspace_users_destroy(self) -> None:
        """Test case for providers_google_workspace_users_destroy

        """
        pass

    def test_providers_google_workspace_users_list(self) -> None:
        """Test case for providers_google_workspace_users_list

        """
        pass

    def test_providers_google_workspace_users_retrieve(self) -> None:
        """Test case for providers_google_workspace_users_retrieve

        """
        pass

    def test_providers_google_workspace_users_used_by_list(self) -> None:
        """Test case for providers_google_workspace_users_used_by_list

        """
        pass

    def test_providers_ldap_create(self) -> None:
        """Test case for providers_ldap_create

        """
        pass

    def test_providers_ldap_destroy(self) -> None:
        """Test case for providers_ldap_destroy

        """
        pass

    def test_providers_ldap_list(self) -> None:
        """Test case for providers_ldap_list

        """
        pass

    def test_providers_ldap_partial_update(self) -> None:
        """Test case for providers_ldap_partial_update

        """
        pass

    def test_providers_ldap_retrieve(self) -> None:
        """Test case for providers_ldap_retrieve

        """
        pass

    def test_providers_ldap_update(self) -> None:
        """Test case for providers_ldap_update

        """
        pass

    def test_providers_ldap_used_by_list(self) -> None:
        """Test case for providers_ldap_used_by_list

        """
        pass

    def test_providers_microsoft_entra_create(self) -> None:
        """Test case for providers_microsoft_entra_create

        """
        pass

    def test_providers_microsoft_entra_destroy(self) -> None:
        """Test case for providers_microsoft_entra_destroy

        """
        pass

    def test_providers_microsoft_entra_groups_create(self) -> None:
        """Test case for providers_microsoft_entra_groups_create

        """
        pass

    def test_providers_microsoft_entra_groups_destroy(self) -> None:
        """Test case for providers_microsoft_entra_groups_destroy

        """
        pass

    def test_providers_microsoft_entra_groups_list(self) -> None:
        """Test case for providers_microsoft_entra_groups_list

        """
        pass

    def test_providers_microsoft_entra_groups_retrieve(self) -> None:
        """Test case for providers_microsoft_entra_groups_retrieve

        """
        pass

    def test_providers_microsoft_entra_groups_used_by_list(self) -> None:
        """Test case for providers_microsoft_entra_groups_used_by_list

        """
        pass

    def test_providers_microsoft_entra_list(self) -> None:
        """Test case for providers_microsoft_entra_list

        """
        pass

    def test_providers_microsoft_entra_partial_update(self) -> None:
        """Test case for providers_microsoft_entra_partial_update

        """
        pass

    def test_providers_microsoft_entra_retrieve(self) -> None:
        """Test case for providers_microsoft_entra_retrieve

        """
        pass

    def test_providers_microsoft_entra_sync_object_create(self) -> None:
        """Test case for providers_microsoft_entra_sync_object_create

        """
        pass

    def test_providers_microsoft_entra_sync_status_retrieve(self) -> None:
        """Test case for providers_microsoft_entra_sync_status_retrieve

        """
        pass

    def test_providers_microsoft_entra_update(self) -> None:
        """Test case for providers_microsoft_entra_update

        """
        pass

    def test_providers_microsoft_entra_used_by_list(self) -> None:
        """Test case for providers_microsoft_entra_used_by_list

        """
        pass

    def test_providers_microsoft_entra_users_create(self) -> None:
        """Test case for providers_microsoft_entra_users_create

        """
        pass

    def test_providers_microsoft_entra_users_destroy(self) -> None:
        """Test case for providers_microsoft_entra_users_destroy

        """
        pass

    def test_providers_microsoft_entra_users_list(self) -> None:
        """Test case for providers_microsoft_entra_users_list

        """
        pass

    def test_providers_microsoft_entra_users_retrieve(self) -> None:
        """Test case for providers_microsoft_entra_users_retrieve

        """
        pass

    def test_providers_microsoft_entra_users_used_by_list(self) -> None:
        """Test case for providers_microsoft_entra_users_used_by_list

        """
        pass

    def test_providers_oauth2_create(self) -> None:
        """Test case for providers_oauth2_create

        """
        pass

    def test_providers_oauth2_destroy(self) -> None:
        """Test case for providers_oauth2_destroy

        """
        pass

    def test_providers_oauth2_list(self) -> None:
        """Test case for providers_oauth2_list

        """
        pass

    def test_providers_oauth2_partial_update(self) -> None:
        """Test case for providers_oauth2_partial_update

        """
        pass

    def test_providers_oauth2_preview_user_retrieve(self) -> None:
        """Test case for providers_oauth2_preview_user_retrieve

        """
        pass

    def test_providers_oauth2_retrieve(self) -> None:
        """Test case for providers_oauth2_retrieve

        """
        pass

    def test_providers_oauth2_setup_urls_retrieve(self) -> None:
        """Test case for providers_oauth2_setup_urls_retrieve

        """
        pass

    def test_providers_oauth2_update(self) -> None:
        """Test case for providers_oauth2_update

        """
        pass

    def test_providers_oauth2_used_by_list(self) -> None:
        """Test case for providers_oauth2_used_by_list

        """
        pass

    def test_providers_proxy_create(self) -> None:
        """Test case for providers_proxy_create

        """
        pass

    def test_providers_proxy_destroy(self) -> None:
        """Test case for providers_proxy_destroy

        """
        pass

    def test_providers_proxy_list(self) -> None:
        """Test case for providers_proxy_list

        """
        pass

    def test_providers_proxy_partial_update(self) -> None:
        """Test case for providers_proxy_partial_update

        """
        pass

    def test_providers_proxy_retrieve(self) -> None:
        """Test case for providers_proxy_retrieve

        """
        pass

    def test_providers_proxy_update(self) -> None:
        """Test case for providers_proxy_update

        """
        pass

    def test_providers_proxy_used_by_list(self) -> None:
        """Test case for providers_proxy_used_by_list

        """
        pass

    def test_providers_rac_create(self) -> None:
        """Test case for providers_rac_create

        """
        pass

    def test_providers_rac_destroy(self) -> None:
        """Test case for providers_rac_destroy

        """
        pass

    def test_providers_rac_list(self) -> None:
        """Test case for providers_rac_list

        """
        pass

    def test_providers_rac_partial_update(self) -> None:
        """Test case for providers_rac_partial_update

        """
        pass

    def test_providers_rac_retrieve(self) -> None:
        """Test case for providers_rac_retrieve

        """
        pass

    def test_providers_rac_update(self) -> None:
        """Test case for providers_rac_update

        """
        pass

    def test_providers_rac_used_by_list(self) -> None:
        """Test case for providers_rac_used_by_list

        """
        pass

    def test_providers_radius_create(self) -> None:
        """Test case for providers_radius_create

        """
        pass

    def test_providers_radius_destroy(self) -> None:
        """Test case for providers_radius_destroy

        """
        pass

    def test_providers_radius_list(self) -> None:
        """Test case for providers_radius_list

        """
        pass

    def test_providers_radius_partial_update(self) -> None:
        """Test case for providers_radius_partial_update

        """
        pass

    def test_providers_radius_retrieve(self) -> None:
        """Test case for providers_radius_retrieve

        """
        pass

    def test_providers_radius_update(self) -> None:
        """Test case for providers_radius_update

        """
        pass

    def test_providers_radius_used_by_list(self) -> None:
        """Test case for providers_radius_used_by_list

        """
        pass

    def test_providers_saml_create(self) -> None:
        """Test case for providers_saml_create

        """
        pass

    def test_providers_saml_destroy(self) -> None:
        """Test case for providers_saml_destroy

        """
        pass

    def test_providers_saml_import_metadata_create(self) -> None:
        """Test case for providers_saml_import_metadata_create

        """
        pass

    def test_providers_saml_list(self) -> None:
        """Test case for providers_saml_list

        """
        pass

    def test_providers_saml_metadata_retrieve(self) -> None:
        """Test case for providers_saml_metadata_retrieve

        """
        pass

    def test_providers_saml_partial_update(self) -> None:
        """Test case for providers_saml_partial_update

        """
        pass

    def test_providers_saml_preview_user_retrieve(self) -> None:
        """Test case for providers_saml_preview_user_retrieve

        """
        pass

    def test_providers_saml_retrieve(self) -> None:
        """Test case for providers_saml_retrieve

        """
        pass

    def test_providers_saml_update(self) -> None:
        """Test case for providers_saml_update

        """
        pass

    def test_providers_saml_used_by_list(self) -> None:
        """Test case for providers_saml_used_by_list

        """
        pass

    def test_providers_scim_create(self) -> None:
        """Test case for providers_scim_create

        """
        pass

    def test_providers_scim_destroy(self) -> None:
        """Test case for providers_scim_destroy

        """
        pass

    def test_providers_scim_groups_create(self) -> None:
        """Test case for providers_scim_groups_create

        """
        pass

    def test_providers_scim_groups_destroy(self) -> None:
        """Test case for providers_scim_groups_destroy

        """
        pass

    def test_providers_scim_groups_list(self) -> None:
        """Test case for providers_scim_groups_list

        """
        pass

    def test_providers_scim_groups_retrieve(self) -> None:
        """Test case for providers_scim_groups_retrieve

        """
        pass

    def test_providers_scim_groups_used_by_list(self) -> None:
        """Test case for providers_scim_groups_used_by_list

        """
        pass

    def test_providers_scim_list(self) -> None:
        """Test case for providers_scim_list

        """
        pass

    def test_providers_scim_partial_update(self) -> None:
        """Test case for providers_scim_partial_update

        """
        pass

    def test_providers_scim_retrieve(self) -> None:
        """Test case for providers_scim_retrieve

        """
        pass

    def test_providers_scim_sync_object_create(self) -> None:
        """Test case for providers_scim_sync_object_create

        """
        pass

    def test_providers_scim_sync_status_retrieve(self) -> None:
        """Test case for providers_scim_sync_status_retrieve

        """
        pass

    def test_providers_scim_update(self) -> None:
        """Test case for providers_scim_update

        """
        pass

    def test_providers_scim_used_by_list(self) -> None:
        """Test case for providers_scim_used_by_list

        """
        pass

    def test_providers_scim_users_create(self) -> None:
        """Test case for providers_scim_users_create

        """
        pass

    def test_providers_scim_users_destroy(self) -> None:
        """Test case for providers_scim_users_destroy

        """
        pass

    def test_providers_scim_users_list(self) -> None:
        """Test case for providers_scim_users_list

        """
        pass

    def test_providers_scim_users_retrieve(self) -> None:
        """Test case for providers_scim_users_retrieve

        """
        pass

    def test_providers_scim_users_used_by_list(self) -> None:
        """Test case for providers_scim_users_used_by_list

        """
        pass

    def test_providers_ssf_create(self) -> None:
        """Test case for providers_ssf_create

        """
        pass

    def test_providers_ssf_destroy(self) -> None:
        """Test case for providers_ssf_destroy

        """
        pass

    def test_providers_ssf_list(self) -> None:
        """Test case for providers_ssf_list

        """
        pass

    def test_providers_ssf_partial_update(self) -> None:
        """Test case for providers_ssf_partial_update

        """
        pass

    def test_providers_ssf_retrieve(self) -> None:
        """Test case for providers_ssf_retrieve

        """
        pass

    def test_providers_ssf_update(self) -> None:
        """Test case for providers_ssf_update

        """
        pass

    def test_providers_ssf_used_by_list(self) -> None:
        """Test case for providers_ssf_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
