# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.authenticator_sms_challenge import AuthenticatorSMSChallenge

class TestAuthenticatorSMSChallenge(unittest.TestCase):
    """AuthenticatorSMSChallenge unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuthenticatorSMSChallenge:
        """Test AuthenticatorSMSChallenge
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuthenticatorSMSChallenge`
        """
        model = AuthenticatorSMSChallenge()
        if include_optional:
            return AuthenticatorSMSChallenge(
                flow_info = authentik_client.models.contextual_flow_info.ContextualFlowInfo(
                    title = '', 
                    background = '', 
                    cancel_url = '', 
                    layout = 'stacked', ),
                component = 'ak-stage-authenticator-sms',
                response_errors = {
                    'key' : [
                        authentik_client.models.error_detail.ErrorDetail(
                            string = '', 
                            code = '', )
                        ]
                    },
                pending_user = '',
                pending_user_avatar = '',
                phone_number_required = True
            )
        else:
            return AuthenticatorSMSChallenge(
                pending_user = '',
                pending_user_avatar = '',
        )
        """

    def testAuthenticatorSMSChallenge(self):
        """Test AuthenticatorSMSChallenge"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
