# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.root_api import RootApi


class TestRootApi(unittest.TestCase):
    """RootApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RootApi()

    def tearDown(self) -> None:
        pass

    def test_root_config_retrieve(self) -> None:
        """Test case for root_config_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
