# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.system_task import SystemTask

class TestSystemTask(unittest.TestCase):
    """SystemTask unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SystemTask:
        """Test SystemTask
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SystemTask`
        """
        model = SystemTask()
        if include_optional:
            return SystemTask(
                uuid = '',
                name = '',
                full_name = '',
                uid = '',
                description = '',
                start_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                finish_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                duration = 1.337,
                status = 'unknown',
                messages = [
                    authentik_client.models.log_event.LogEvent(
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        log_level = 'critical', 
                        logger = '', 
                        event = '', 
                        attributes = {
                            'key' : null
                            }, )
                    ],
                expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                expiring = True
            )
        else:
            return SystemTask(
                uuid = '',
                name = '',
                full_name = '',
                description = '',
                start_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                finish_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                duration = 1.337,
                status = 'unknown',
                messages = [
                    authentik_client.models.log_event.LogEvent(
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        log_level = 'critical', 
                        logger = '', 
                        event = '', 
                        attributes = {
                            'key' : null
                            }, )
                    ],
        )
        """

    def testSystemTask(self):
        """Test SystemTask"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
