# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.authenticators_api import AuthenticatorsApi


class TestAuthenticatorsApi(unittest.TestCase):
    """AuthenticatorsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthenticatorsApi()

    def tearDown(self) -> None:
        pass

    def test_authenticators_admin_all_list(self) -> None:
        """Test case for authenticators_admin_all_list

        """
        pass

    def test_authenticators_admin_duo_create(self) -> None:
        """Test case for authenticators_admin_duo_create

        """
        pass

    def test_authenticators_admin_duo_destroy(self) -> None:
        """Test case for authenticators_admin_duo_destroy

        """
        pass

    def test_authenticators_admin_duo_list(self) -> None:
        """Test case for authenticators_admin_duo_list

        """
        pass

    def test_authenticators_admin_duo_partial_update(self) -> None:
        """Test case for authenticators_admin_duo_partial_update

        """
        pass

    def test_authenticators_admin_duo_retrieve(self) -> None:
        """Test case for authenticators_admin_duo_retrieve

        """
        pass

    def test_authenticators_admin_duo_update(self) -> None:
        """Test case for authenticators_admin_duo_update

        """
        pass

    def test_authenticators_admin_email_create(self) -> None:
        """Test case for authenticators_admin_email_create

        """
        pass

    def test_authenticators_admin_email_destroy(self) -> None:
        """Test case for authenticators_admin_email_destroy

        """
        pass

    def test_authenticators_admin_email_list(self) -> None:
        """Test case for authenticators_admin_email_list

        """
        pass

    def test_authenticators_admin_email_partial_update(self) -> None:
        """Test case for authenticators_admin_email_partial_update

        """
        pass

    def test_authenticators_admin_email_retrieve(self) -> None:
        """Test case for authenticators_admin_email_retrieve

        """
        pass

    def test_authenticators_admin_email_update(self) -> None:
        """Test case for authenticators_admin_email_update

        """
        pass

    def test_authenticators_admin_endpoint_create(self) -> None:
        """Test case for authenticators_admin_endpoint_create

        """
        pass

    def test_authenticators_admin_endpoint_destroy(self) -> None:
        """Test case for authenticators_admin_endpoint_destroy

        """
        pass

    def test_authenticators_admin_endpoint_list(self) -> None:
        """Test case for authenticators_admin_endpoint_list

        """
        pass

    def test_authenticators_admin_endpoint_partial_update(self) -> None:
        """Test case for authenticators_admin_endpoint_partial_update

        """
        pass

    def test_authenticators_admin_endpoint_retrieve(self) -> None:
        """Test case for authenticators_admin_endpoint_retrieve

        """
        pass

    def test_authenticators_admin_endpoint_update(self) -> None:
        """Test case for authenticators_admin_endpoint_update

        """
        pass

    def test_authenticators_admin_sms_create(self) -> None:
        """Test case for authenticators_admin_sms_create

        """
        pass

    def test_authenticators_admin_sms_destroy(self) -> None:
        """Test case for authenticators_admin_sms_destroy

        """
        pass

    def test_authenticators_admin_sms_list(self) -> None:
        """Test case for authenticators_admin_sms_list

        """
        pass

    def test_authenticators_admin_sms_partial_update(self) -> None:
        """Test case for authenticators_admin_sms_partial_update

        """
        pass

    def test_authenticators_admin_sms_retrieve(self) -> None:
        """Test case for authenticators_admin_sms_retrieve

        """
        pass

    def test_authenticators_admin_sms_update(self) -> None:
        """Test case for authenticators_admin_sms_update

        """
        pass

    def test_authenticators_admin_static_create(self) -> None:
        """Test case for authenticators_admin_static_create

        """
        pass

    def test_authenticators_admin_static_destroy(self) -> None:
        """Test case for authenticators_admin_static_destroy

        """
        pass

    def test_authenticators_admin_static_list(self) -> None:
        """Test case for authenticators_admin_static_list

        """
        pass

    def test_authenticators_admin_static_partial_update(self) -> None:
        """Test case for authenticators_admin_static_partial_update

        """
        pass

    def test_authenticators_admin_static_retrieve(self) -> None:
        """Test case for authenticators_admin_static_retrieve

        """
        pass

    def test_authenticators_admin_static_update(self) -> None:
        """Test case for authenticators_admin_static_update

        """
        pass

    def test_authenticators_admin_totp_create(self) -> None:
        """Test case for authenticators_admin_totp_create

        """
        pass

    def test_authenticators_admin_totp_destroy(self) -> None:
        """Test case for authenticators_admin_totp_destroy

        """
        pass

    def test_authenticators_admin_totp_list(self) -> None:
        """Test case for authenticators_admin_totp_list

        """
        pass

    def test_authenticators_admin_totp_partial_update(self) -> None:
        """Test case for authenticators_admin_totp_partial_update

        """
        pass

    def test_authenticators_admin_totp_retrieve(self) -> None:
        """Test case for authenticators_admin_totp_retrieve

        """
        pass

    def test_authenticators_admin_totp_update(self) -> None:
        """Test case for authenticators_admin_totp_update

        """
        pass

    def test_authenticators_admin_webauthn_create(self) -> None:
        """Test case for authenticators_admin_webauthn_create

        """
        pass

    def test_authenticators_admin_webauthn_destroy(self) -> None:
        """Test case for authenticators_admin_webauthn_destroy

        """
        pass

    def test_authenticators_admin_webauthn_list(self) -> None:
        """Test case for authenticators_admin_webauthn_list

        """
        pass

    def test_authenticators_admin_webauthn_partial_update(self) -> None:
        """Test case for authenticators_admin_webauthn_partial_update

        """
        pass

    def test_authenticators_admin_webauthn_retrieve(self) -> None:
        """Test case for authenticators_admin_webauthn_retrieve

        """
        pass

    def test_authenticators_admin_webauthn_update(self) -> None:
        """Test case for authenticators_admin_webauthn_update

        """
        pass

    def test_authenticators_all_list(self) -> None:
        """Test case for authenticators_all_list

        """
        pass

    def test_authenticators_duo_destroy(self) -> None:
        """Test case for authenticators_duo_destroy

        """
        pass

    def test_authenticators_duo_list(self) -> None:
        """Test case for authenticators_duo_list

        """
        pass

    def test_authenticators_duo_partial_update(self) -> None:
        """Test case for authenticators_duo_partial_update

        """
        pass

    def test_authenticators_duo_retrieve(self) -> None:
        """Test case for authenticators_duo_retrieve

        """
        pass

    def test_authenticators_duo_update(self) -> None:
        """Test case for authenticators_duo_update

        """
        pass

    def test_authenticators_duo_used_by_list(self) -> None:
        """Test case for authenticators_duo_used_by_list

        """
        pass

    def test_authenticators_email_destroy(self) -> None:
        """Test case for authenticators_email_destroy

        """
        pass

    def test_authenticators_email_list(self) -> None:
        """Test case for authenticators_email_list

        """
        pass

    def test_authenticators_email_partial_update(self) -> None:
        """Test case for authenticators_email_partial_update

        """
        pass

    def test_authenticators_email_retrieve(self) -> None:
        """Test case for authenticators_email_retrieve

        """
        pass

    def test_authenticators_email_update(self) -> None:
        """Test case for authenticators_email_update

        """
        pass

    def test_authenticators_email_used_by_list(self) -> None:
        """Test case for authenticators_email_used_by_list

        """
        pass

    def test_authenticators_endpoint_list(self) -> None:
        """Test case for authenticators_endpoint_list

        """
        pass

    def test_authenticators_endpoint_retrieve(self) -> None:
        """Test case for authenticators_endpoint_retrieve

        """
        pass

    def test_authenticators_endpoint_used_by_list(self) -> None:
        """Test case for authenticators_endpoint_used_by_list

        """
        pass

    def test_authenticators_sms_destroy(self) -> None:
        """Test case for authenticators_sms_destroy

        """
        pass

    def test_authenticators_sms_list(self) -> None:
        """Test case for authenticators_sms_list

        """
        pass

    def test_authenticators_sms_partial_update(self) -> None:
        """Test case for authenticators_sms_partial_update

        """
        pass

    def test_authenticators_sms_retrieve(self) -> None:
        """Test case for authenticators_sms_retrieve

        """
        pass

    def test_authenticators_sms_update(self) -> None:
        """Test case for authenticators_sms_update

        """
        pass

    def test_authenticators_sms_used_by_list(self) -> None:
        """Test case for authenticators_sms_used_by_list

        """
        pass

    def test_authenticators_static_destroy(self) -> None:
        """Test case for authenticators_static_destroy

        """
        pass

    def test_authenticators_static_list(self) -> None:
        """Test case for authenticators_static_list

        """
        pass

    def test_authenticators_static_partial_update(self) -> None:
        """Test case for authenticators_static_partial_update

        """
        pass

    def test_authenticators_static_retrieve(self) -> None:
        """Test case for authenticators_static_retrieve

        """
        pass

    def test_authenticators_static_update(self) -> None:
        """Test case for authenticators_static_update

        """
        pass

    def test_authenticators_static_used_by_list(self) -> None:
        """Test case for authenticators_static_used_by_list

        """
        pass

    def test_authenticators_totp_destroy(self) -> None:
        """Test case for authenticators_totp_destroy

        """
        pass

    def test_authenticators_totp_list(self) -> None:
        """Test case for authenticators_totp_list

        """
        pass

    def test_authenticators_totp_partial_update(self) -> None:
        """Test case for authenticators_totp_partial_update

        """
        pass

    def test_authenticators_totp_retrieve(self) -> None:
        """Test case for authenticators_totp_retrieve

        """
        pass

    def test_authenticators_totp_update(self) -> None:
        """Test case for authenticators_totp_update

        """
        pass

    def test_authenticators_totp_used_by_list(self) -> None:
        """Test case for authenticators_totp_used_by_list

        """
        pass

    def test_authenticators_webauthn_destroy(self) -> None:
        """Test case for authenticators_webauthn_destroy

        """
        pass

    def test_authenticators_webauthn_list(self) -> None:
        """Test case for authenticators_webauthn_list

        """
        pass

    def test_authenticators_webauthn_partial_update(self) -> None:
        """Test case for authenticators_webauthn_partial_update

        """
        pass

    def test_authenticators_webauthn_retrieve(self) -> None:
        """Test case for authenticators_webauthn_retrieve

        """
        pass

    def test_authenticators_webauthn_update(self) -> None:
        """Test case for authenticators_webauthn_update

        """
        pass

    def test_authenticators_webauthn_used_by_list(self) -> None:
        """Test case for authenticators_webauthn_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
