# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.enterprise_api import EnterpriseApi


class TestEnterpriseApi(unittest.TestCase):
    """EnterpriseApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EnterpriseApi()

    def tearDown(self) -> None:
        pass

    def test_enterprise_license_create(self) -> None:
        """Test case for enterprise_license_create

        """
        pass

    def test_enterprise_license_destroy(self) -> None:
        """Test case for enterprise_license_destroy

        """
        pass

    def test_enterprise_license_forecast_retrieve(self) -> None:
        """Test case for enterprise_license_forecast_retrieve

        """
        pass

    def test_enterprise_license_install_id_retrieve(self) -> None:
        """Test case for enterprise_license_install_id_retrieve

        """
        pass

    def test_enterprise_license_list(self) -> None:
        """Test case for enterprise_license_list

        """
        pass

    def test_enterprise_license_partial_update(self) -> None:
        """Test case for enterprise_license_partial_update

        """
        pass

    def test_enterprise_license_retrieve(self) -> None:
        """Test case for enterprise_license_retrieve

        """
        pass

    def test_enterprise_license_summary_retrieve(self) -> None:
        """Test case for enterprise_license_summary_retrieve

        """
        pass

    def test_enterprise_license_update(self) -> None:
        """Test case for enterprise_license_update

        """
        pass

    def test_enterprise_license_used_by_list(self) -> None:
        """Test case for enterprise_license_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
