# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.flow_stage_binding import FlowStageBinding

class TestFlowStageBinding(unittest.TestCase):
    """FlowStageBinding unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlowStageBinding:
        """Test FlowStageBinding
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlowStageBinding`
        """
        model = FlowStageBinding()
        if include_optional:
            return FlowStageBinding(
                pk = '',
                policybindingmodel_ptr_id = '',
                target = '',
                stage = '',
                stage_obj = authentik_client.models.stage.Stage(
                    pk = '', 
                    name = '', 
                    component = '', 
                    verbose_name = '', 
                    verbose_name_plural = '', 
                    meta_model_name = '', 
                    flow_set = [
                        authentik_client.models.flow_set.FlowSet(
                            pk = '', 
                            policybindingmodel_ptr_id = '', 
                            name = '', 
                            slug = 'z', 
                            title = '', 
                            designation = null, 
                            background = '', 
                            policy_engine_mode = 'all', 
                            compatibility_mode = True, 
                            export_url = '', 
                            layout = 'stacked', 
                            denied_action = null, )
                        ], ),
                evaluate_on_plan = True,
                re_evaluate_policies = True,
                order = -2147483648,
                policy_engine_mode = 'all',
                invalid_response_action = 'retry'
            )
        else:
            return FlowStageBinding(
                pk = '',
                policybindingmodel_ptr_id = '',
                target = '',
                stage = '',
                stage_obj = authentik_client.models.stage.Stage(
                    pk = '', 
                    name = '', 
                    component = '', 
                    verbose_name = '', 
                    verbose_name_plural = '', 
                    meta_model_name = '', 
                    flow_set = [
                        authentik_client.models.flow_set.FlowSet(
                            pk = '', 
                            policybindingmodel_ptr_id = '', 
                            name = '', 
                            slug = 'z', 
                            title = '', 
                            designation = null, 
                            background = '', 
                            policy_engine_mode = 'all', 
                            compatibility_mode = True, 
                            export_url = '', 
                            layout = 'stacked', 
                            denied_action = null, )
                        ], ),
                order = -2147483648,
        )
        """

    def testFlowStageBinding(self):
        """Test FlowStageBinding"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
