# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.o_auth2_provider_request import OAuth2ProviderRequest

class TestOAuth2ProviderRequest(unittest.TestCase):
    """OAuth2ProviderRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OAuth2ProviderRequest:
        """Test OAuth2ProviderRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OAuth2ProviderRequest`
        """
        model = OAuth2ProviderRequest()
        if include_optional:
            return OAuth2ProviderRequest(
                name = '0',
                authentication_flow = '',
                authorization_flow = '',
                invalidation_flow = '',
                property_mappings = [
                    ''
                    ],
                client_type = 'confidential',
                client_id = '0',
                client_secret = '',
                access_code_validity = '0',
                access_token_validity = '0',
                refresh_token_validity = '0',
                include_claims_in_id_token = True,
                signing_key = '',
                encryption_key = '',
                redirect_uris = [
                    authentik_client.models.redirect_uri_request.RedirectURIRequest(
                        matching_mode = 'strict', 
                        url = '0', )
                    ],
                sub_mode = 'hashed_user_id',
                issuer_mode = 'global',
                jwt_federation_sources = [
                    ''
                    ],
                jwt_federation_providers = [
                    56
                    ]
            )
        else:
            return OAuth2ProviderRequest(
                name = '0',
                authorization_flow = '',
                invalidation_flow = '',
                redirect_uris = [
                    authentik_client.models.redirect_uri_request.RedirectURIRequest(
                        matching_mode = 'strict', 
                        url = '0', )
                    ],
        )
        """

    def testOAuth2ProviderRequest(self):
        """Test OAuth2ProviderRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
