# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.0
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.flow import Flow

class TestFlow(unittest.TestCase):
    """Flow unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Flow:
        """Test Flow
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Flow`
        """
        model = Flow()
        if include_optional:
            return Flow(
                pk = '',
                policybindingmodel_ptr_id = '',
                name = '',
                slug = 'z',
                title = '',
                designation = 'authentication',
                background = '',
                stages = [
                    ''
                    ],
                policies = [
                    ''
                    ],
                cache_count = 56,
                policy_engine_mode = 'all',
                compatibility_mode = True,
                export_url = '',
                layout = 'stacked',
                denied_action = 'message_continue',
                authentication = 'none'
            )
        else:
            return Flow(
                pk = '',
                policybindingmodel_ptr_id = '',
                name = '',
                slug = 'z',
                title = '',
                designation = 'authentication',
                background = '',
                stages = [
                    ''
                    ],
                policies = [
                    ''
                    ],
                cache_count = 56,
                export_url = '',
        )
        """

    def testFlow(self):
        """Test Flow"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
